@@ -13,6 +13,7 @@ class DlgConfig:
       self.confFile = os.path.join(confDir, "qonso.conf")
       self.conf = ConfigParser()
       self.LoadConfig()
+      self.updated = False
 
    def LoadConfig(self):
       if os.path.exists(self.confFile):
@@ -136,6 +137,7 @@ class DlgConfig:
    def OnOK(self):
       self.SetCredentials( (self.login.text(), self.password.text()) )
       self.SetOperator( self.comboop.currentText() )
+      self.updated = True
       self.dlg.accept()
 
    def OnCancel(self):
