@@ -23,7 +23,8 @@ class QonsoExtractor:
       self.context = ''
       self.status = ''
       self.offline = True
-      self.SetStatus('INFO', 'Connexion au site...')
+      self.SetStatus('INFO', 'Connexion...')
+      self.progress = 0
       
    def SetView(self, view):
       self.view = view
@@ -37,6 +38,9 @@ class QonsoExtractor:
    def SetOffline(self, offline):
       self.offline = offline
 
+   def GetProgress(self):
+      return self.progress
+      
    def SetStatus(self, status, context):
       DebugLog(status+" : "+context)
       self.context = context
@@ -65,6 +69,7 @@ class QonsoExtractor:
       request = QNetworkRequest()
       request.setUrl( QtCore.QUrl(self.urlbeforeAuth ) ) 
       self.manager.get(request)
+      self.progress = 33
 
    def Authenticate(self, idCorrelation):
       pass
@@ -75,6 +80,7 @@ class QonsoExtractor:
       DebugLog(self.authentication)
       # test d'erreur, en général, pas de connection internet
       if error != QNetworkReply.NoError:
+         self.progress = 100
          self.SetStatus('ERROR', "Erreur, v&eacute;rifiez votre connection Internet")
       
       # On est bon. On charge la page et on extrait les données
@@ -95,6 +101,7 @@ class QonsoExtractor:
       self.authentication = 'Done'
       request = QNetworkRequest()
       request.setUrl( QtCore.QUrl(self.urlconso) ) 
+      self.progress = 95
       self.SetStatus('INFO', 'R&eacute;cup&eacute;ration des donn&eacute;es...')
       self.manager.get(request)
       
@@ -123,12 +130,16 @@ class QonsoExtractor:
    def ExtractDatas(self, datas):
       DebugLog("QonsoExtractor::ExtractDatas")
       
+      self.progress = 100
       self.SetStatus('INFO', 'Extraction des donn&eacute;es...')
+      
       DebugFile(datas)
       self.DoExtractDatas( str(datas) )
       self.datasExtracted = True
       
       DebugLog('----------------------------------------------\nQonsoExtractor::ExtractDatas done')
+      if self.status != 'ERROR':
+         self.SetStatus('DONE', 'Termin&eacute;')
       
       if self.view:
          DebugLog("QonsoExtractor:: update view")
