@@ -53,7 +53,7 @@ class QonsoModel:
    
       
    def ExtractTime(self, s):
-      s = s.replace('\n', '')
+      s = s.replace('\n', '').replace('\r', '')
       res = self.regHM.search(s)
       timenum = 0
       timestr = "0 min"
