@@ -114,7 +114,7 @@ class QonsoView(QtGui.QMainWindow):
 
       self.statusBox = self.CreateLayout('status', None, True)
       # self.labels['status'][1].setRange( 0, 100 )
-      # self.labels['status'][1].setShowRules(False)
+      self.labels['status'][1].setShowRules(False)
       # self.labels['status'][1].setYTop(0)
       
       self.vbox.addLayout(self.statusBox)
@@ -220,19 +220,9 @@ class QonsoView(QtGui.QMainWindow):
          self.labels['status'][1].hide()
          
       else:
-         context = context.strip()
-         pos = context.find(".")
-         if pos>1:
-            ppp = context[pos+1:]
-            ppplen = (len(ppp)+1)%4
-            context = context[:pos] + (1+ppplen)*"." + (3-ppplen)*" "
-
          self.SetText(self.labels['status'][0], "#269CCA", 16, context)
-         self.labels['status'][0].setAlignment(QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
-         self.labels['status'][0].setStyleSheet("padding-left: 200px; background: white")
          self.labels['status'][1].setValue( self.extractor.GetProgress() )
-         self.extractor.context = context
-         time.sleep(0.3)
+         time.sleep(0.005)
          self.update()
          
       if self.model.GetLastTime():
